import re

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('yaml_merge/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

with open('README.rst') as f:
    readme = f.read()
with open('CHANGELOG.rst') as f:
    changelog = f.read()
with open('requirements.txt') as f:
    requirements = f.read()

setup(
    name='yaml-merge',
    version=version,
    description='Merge YAML several files into one object.',
    long_description=readme + '\n\n' + changelog,
    author="Adrian Matellanes",
    author_email='matellanesadrian@gmail.com',
    url='https://github.com/amatellanes/yaml-merge',
    install_requires=requirements,
    license='MIT License',
    packages=['yaml_merge'],
    include_package_data=True,
    zip_safe=False,
    entry_points='''
        [console_scripts]
        yaml-merge=yaml_merge:cli
    ''',
    classifiers=(
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: PyPy'
    )
)
