import click
import yaml

__version__ = '0.1.1'


def dict_merge(dct, merge_dct):
    """Recursive dictionaries merge.

    Go down recursively into dicts nested to an arbitrary depth, updating keys.
    The ``merge_dct`` is merged into ``dct``.

    :param dct: Dictionary onto which the merge is executed.
    :type dct: dict
    :param merge_dct: Dictionary merged into ``dct``.
    :type merge_dct: dict
    """
    for k, v in iter(merge_dct.items()):
        if (k in dct and isinstance(dct[k], dict) and
                isinstance(merge_dct[k], dict)):
            dict_merge(dct[k], merge_dct[k])
        else:
            dct[k] = merge_dct[k]


@click.command()
@click.argument('src', nargs=-1, type=click.File())
def cli(src):
    """Merges recursively a list of YAML files."""
    # Check if any file is specified
    if len(src) == 0:
        return None

    # Go through list of source files and merge YAML content
    if src is not None:
        result = {}
        for fname in src:
            content = yaml.safe_load(fname)
            dict_merge(result, content)

        # Write result into stdout
        out = yaml.safe_dump(result, default_flow_style=False)
        click.echo(out)

    if __name__ == '__name__':
        cli()
